import { json, tree, select, cluster, hierarchy } from 'd3';
import ParseGui from './parseGui';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');
var data = [];


const render = () => {
  const length = 20;
  const spacing = 5;
  const getRowSpacing = (i) => (length + spacing) * i;
  const getColumnSpacing = (j) => (length + spacing) * j;
  
  // update & enter selection for sequences
  const rows = svg
    .selectAll('g').data(data);
  const rowsEnter = rows
    .enter().append('g')
      .attr('transform', (d,i) => `translate(20, ${getRowSpacing(i) + 20})`);
  const textEnter = rows
    .enter().append('text')
      .attr('font-family', 'sans-serif')
      .attr('font-size', '20px')
      .attr('fill', 'black')
      .text((d) => d[0].data.count)
      .attr('x', (d) => getColumnSpacing(d.length) + length)
      .attr('y', (d,i) => getRowSpacing(i) + length + 16)
  
  // update & enter selection for events
  const events = rowsEnter
    .selectAll('rect').data((d) => d);
  const eventsEnter = events
    .enter().append('rect')
      .attr('width', length)
      .attr('height', length)
      .attr('fill', 'steelblue')
      .attr('x', (d,j) => getColumnSpacing(j))
}





json('data.json').then((loadedData) => {
  // for(let i in loadedData) {
  //   let guis = ParseGui.parseGuiStr(loadedData[i].GUIText, i, i);
  //   for(let gui of guis) {
  //     data.push(hierarchy(gui).descendants());
  //   }
  // }
  
  // Aggregate Connections By GUIText Value
    let aggData = loadedData.reduce((acc, val, i) => {
    const guiText = val.GUIText;
    const parsedGui = ParseGui.parseGuiStr(guiText, val.id);

    if(acc.hasOwnProperty(guiText)) {
      acc[guiText].count += 1;
      acc[guiText].indexList.push(i);
    } else {
      acc[guiText] = {
        'count': 1,
        'indexList': [i],
        'parsedGui': parsedGui,
      };
    }

    return acc;
  }, {});

  // Set data to D3 descendants of GUI hierarchy
  for(let key in aggData) {
    for(let gui of aggData[key]['parsedGui']) {
      const root = hierarchy(gui);
      root.data.count = aggData[key].count
      data.push(root.descendants());
    }
  }
  
  // Sort data by count value
  data.sort((a,b) => b[0].data.count - a[0].data.count);
  
  // Add index value to each data entry
  for(let i in data) {
    data[i][0].data.index = i;
  }
  
  console.log(aggData);
  console.log(data);
  
  render();
});










