export default class ParseGui {
  static findBeginningIndex(guiStr) {
    var startIndex = 100;
    const params = ['N', 'CN', 'CT', 'Time'];

    for(let param of params) {
      let paramIndex = guiStr.indexOf(param);
      if(paramIndex < startIndex)
        startIndex = paramIndex;
    }

    return startIndex;
  }


  static getAttributePairs(str) {
    // Base Variables
    var res = {};
    var pairs = str.split(',');

    for(let pair of pairs) {
      // Split Pair
      var key, value;
      var kvp = pair.split('=')

      // Ensure Pair
      if(kvp.length == 2) {
        key = kvp[0];
        value = kvp[1];

        // Extract Time as int
        if(key == 'Time') {
          const parsedValue = parseInt(value);
          if(!isNaN(parsedValue))
            value = parsedValue;
        }

        // Set res attribute
        res[key] = value;
      }
    }

    return res;
  }


  static parseAttributes(guiStr, id) {
    // Base Variables
    var res = {};
    var nextIndex = guiStr.indexOf('->');

    // Last child to process
    if(nextIndex === -1)
    {
      res = this.getAttributePairs(guiStr);
      res['event'] = guiStr;
      // res['id'] = id;
      return res;
    }

    // Process next child
    var children = this.parseAttributes(guiStr.slice(nextIndex+2), id);

    // Set res attributes
    var subStr = guiStr.slice(0, nextIndex);
    res = this.getAttributePairs(subStr);
    // res['id'] = id;
    res['event'] = subStr;
    res['children'] = [children];

    return res;
  }

  static parseGuiStr(guiStr, id) {
    // Base Variables
    var guiList = guiStr.split('||');

    // Remove Unwanted Prefix Characters
    var startIndex = this.findBeginningIndex(guiList[0]);
    guiList[0] = guiList[0].slice(startIndex);

    // Iterate Through Each Gui String
    var parsedGuiList = [];
    for(let gui of guiList) {
      // var guiObj = {'id': id, 'index': index};
      var parsedGui = this.parseAttributes(gui, id);

      // guiObj['children'] = parsedGui;
      // parsedGuiList.push(guiObj);

      parsedGui['id'] = id;
      // parsedGui['index'] = index;
      parsedGuiList.push(parsedGui);
    }

    return parsedGuiList;
  }
}
